@@ -39,12 +39,14 @@
 # 01 Feb 2024 by Robin-antiX: Added autosuspend entry. +Fix for startup entries containing slashes or ampersand. Improved startup file management. Sorted hardware tab.
 # 05 Feb 2024 by anticapitalista. fixed typos, added Shared Folders,  added antiX cloud, added Language, put suspend-grey icon in /usr/share/pixmaps/papirus
 # 26 Feb 2024 by Robin fix for user closing installer window prematurely by X in window border; added multilingual keyboard 4 level layout map
-# 13 Jul 2024 by Robin added compositor toggle
-# 28 Jul 2024 by Robin added disk usage analyser
+# 13/28 Jul 2024 by Robin added compositor toggle, disk usage analyser
+# 08 Jul 2025 by Robin added hostname changer, memory manager.
 #
 # Acknowledgements: Original script by KDulcimer of TinyMe. http://tinyme.mypclinuxos.com
 #################################################################################################################################################
 
+version=1.2.8
+
 TEXTDOMAINDIR=/usr/share/locale
 TEXTDOMAIN=antixcc
 
@@ -542,6 +544,13 @@ test -x $process_management_prog && process_entry=$(entry \
     $"Process Manager" \
     $"View, pause, kill or nice processes in a console-gui"" "$"Use mouse for all controls.")
 
+memorymanager_prog=/usr/local/bin/antiX-memory-manager
+test -x $memorymanager_prog && memorymanager_entry=$(entry \
+    $ICONS3/antiXmm.png \
+    "urxvt -e sudo bash -c '/usr/local/bin/antiX-memory-manager &'" \
+    $"Memory Manager" \
+    $"Optimise memory economy by applying kernel memory compression. Activate, deactivate, configure zram and zswap, check usage stats.")
+
 localisation_prog=/usr/local/bin/locale-antix
 test -x $localisation_prog && localisation_entry=$(entry \
     $ICONS/preferences-desktop-locale.png \
@@ -674,6 +683,13 @@ test -x $adblock_prog && adblock_entry=$(entry \
     $"Adblock" \
     $"Block adverts via /etc/hosts file")
 
+hostname_prog=/usr/local/bin/antiX-hostname-changer
+test -x $hostname_prog && hostname_entry=$(entry \
+    $ICONS3/antiXhnc.png \
+    "urxvt -e sudo bash -c 'antiX-hostname-changer &'" \
+    $"Hostname Changer" \
+    $"Changes the Computer name (hostname) in antiX for your local network. As a consequence this will change the displayed computer name in console windows. The hostname must be unique in your local network domain.")
+
 login_prog=/usr/local/bin/login-config-antix
 test -x $login_prog && login_entry=$(entry \
     $ICONS/preferences-system-login.png \
@@ -904,7 +920,7 @@ test -x $pointing_prog && pointing_entry=$(entry \
     $ICONS/input-mouse.png \
     "antiX-pdm &" \
     $"Pointing Device Manager" \
-    $"Configure keyboard, mouse, and other input devices")
+    $"Configure touchpad, mouse, and other pointing input devices")
 
 soundcard_prog=/usr/local/bin/alsa-set-default-card
 test -x $soundcard_prog && soundcard_entry=$(entry \
@@ -1109,10 +1125,10 @@ $(vbox_frame_hbox \
 
 $(vbox_frame_hbox \
 "$(vbox "$icewmgui_entry" "$sysvconf_entry"  "$runitconf_entry" "$galternatives_entry" "$localisation_entry" "$compositor_entry" )" \
-"$(vbox "$confroot_entry" "$systemkeyboard_entry" "$keyboardlayout_entry" "$tzdata_entry" "$process_entry")" )
+"$(vbox "$confroot_entry" "$systemkeyboard_entry" "$keyboardlayout_entry" "$tzdata_entry" "$process_entry" "$memorymanager_entry")" )
 
 $(vbox_frame_hbox \
-"$(vbox "$wifi_entry $connman_entry" "$ceni_entry" "$pppoeconf_entry" )" \
+"$(vbox "$wifi_entry $connman_entry" "$ceni_entry" "$pppoeconf_entry" "$hostname_entry")" \
 "$(vbox "$gnomeppp_entry" "$wpasupplicant_entry" "$firewall_entry" "$adblock_entry" "$ufwtoggle_entry")" )
 
 $(vbox_frame_hbox \
